==> vue3-components-0.0.7.tgz: package/es/selectArea/src/selectArea.vue_vue_type_script_setup_true_lang.js <==
import { defineComponent as y, ref as v, computed as F, watch as i, resolveComponent as f, openBlock as c, createBlock as d, normalizeClass as k, unref as s, withCtx as m, createVNode as b, mergeProps as _, createElementBlock as V, Fragment as A, renderList as E } from "vue";
import { selectAreaProps as w } from "./selectArea2.js";
import { createNamespacs as U } from "../../utils/es/src/create.js";
import B from "./lib/pac-code.js";
const N = {
  name: "KSelectArea"
}, S = /* @__PURE__ */ y({
  ...N,
  props: w,
  emits: ["change"],
  setup(P, { emit: g }) {
    const D = U("progress"), u = v(), t = v(), n = v(), p = F(
      () => {
        var a;
        return ((a = B.find((l) => l.code === u.value)) == null ? void 0 : a.children) || [];
      }
    ), C = F(
      () => {
        var a, l;
        return ((l = (a = p.value) == null ? void 0 : a.find((r) => r.code === t.value)) == null ? void 0 : l.children) || [];
      }
    );
    return i(u, () => {
      t.value = "";
    }), i(t, () => {
      n.value = "";
    }), i(n, () => {
      if (!n.value)
        return;
      const a = {
        code: u.value,
        name: B.find((o) => o.code === u.value).name
      }, l = {
        code: t.value,
        name: p.value.find(
          (o) => o.code === t.value
        ).name
      }, r = {
        code: n.value,
        name: C.value.find(
          (o) => o.code === n.value
        ).name
      };
      g("change", { provinceData: a, cityData: l, areaData: r });
    }), (a, l) => {
      const r = f("el-option"), o = f("el-select"), h = f("el-space");
      return c(), d(h, {
        wrap: "",
        class: k(s(D).b())
      }, {
        default: m(() => [
          b(o, _({
            modelValue: u.value,
            "onUpdate:modelValue": l[0] || (l[0] = (e) => u.value = e),
            placeholder: "\u8BF7\u9009\u62E9\u7701\u4EFD",
            clearable: "",
            filterable: ""
          }, a.provinceAttrs), {
            default: m(() => [
              (c(!0), V(A, null, E(s(B), (e) => (c(), d(r, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue"]),
          b(o, _({
            modelValue: t.value,
            "onUpdate:modelValue": l[1] || (l[1] = (e) => t.value = e),
            placeholder: "\u8BF7\u9009\u62E9\u57CE\u5E02",
            clearable: "",
            filterable: "",
            disabled: !u.value
          }, a.cityAttrs), {
            default: m(() => [
              (c(!0), V(A, null, E(s(p), (e) => (c(), d(r, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"]),
          b(o, _({
            modelValue: n.value,
            "onUpdate:modelValue": l[2] || (l[2] = (e) => n.value = e),
            placeholder: "\u8BF7\u9009\u62E9\u533A\u57DF",
            clearable: "",
            filterable: "",
            disabled: !u.value || !t.value
          }, a.areaAttrs), {
            default: m(() => [
              (c(!0), V(A, null, E(s(C), (e) => (c(), d(r, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
export {
  S as default
};

==> vue3-components-0.2.3.tgz: package/es/selectArea/src/selectArea.vue_vue_type_script_setup_true_lang.js <==
import { defineComponent as y, ref as v, computed as F, watch as i, resolveComponent as f, openBlock as c, createBlock as d, normalizeClass as k, unref as s, withCtx as m, createVNode as b, mergeProps as _, createElementBlock as V, Fragment as A, renderList as E } from "vue";
import { selectAreaProps as w } from "./selectArea2.js";
import { createNamespacs as U } from "@tomiaa/utils";
import B from "./lib/pac-code.js";
const N = {
  name: "KSelectArea"
}, j = /* @__PURE__ */ y({
  ...N,
  props: w,
  emits: ["change"],
  setup(P, { emit: g }) {
    const D = U("progress"), u = v(), t = v(), n = v(), p = F(
      () => {
        var a;
        return ((a = B.find((l) => l.code === u.value)) == null ? void 0 : a.children) || [];
      }
    ), C = F(
      () => {
        var a, l;
        return ((l = (a = p.value) == null ? void 0 : a.find((r) => r.code === t.value)) == null ? void 0 : l.children) || [];
      }
    );
    return i(u, () => {
      t.value = "";
    }), i(t, () => {
      n.value = "";
    }), i(n, () => {
      if (!n.value)
        return;
      const a = {
        code: u.value,
        name: B.find((o) => o.code === u.value).name
      }, l = {
        code: t.value,
        name: p.value.find(
          (o) => o.code === t.value
        ).name
      }, r = {
        code: n.value,
        name: C.value.find(
          (o) => o.code === n.value
        ).name
      };
      g("change", { provinceData: a, cityData: l, areaData: r });
    }), (a, l) => {
      const r = f("el-option"), o = f("el-select"), h = f("el-space");
      return c(), d(h, {
        wrap: "",
        class: k(s(D).b())
      }, {
        default: m(() => [
          b(o, _({
            modelValue: u.value,
            "onUpdate:modelValue": l[0] || (l[0] = (e) => u.value = e),
            placeholder: "\u8BF7\u9009\u62E9\u7701\u4EFD",
            clearable: "",
            filterable: ""
          }, a.provinceAttrs), {
            default: m(() => [
              (c(!0), V(A, null, E(s(B), (e) => (c(), d(r, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue"]),
          b(o, _({
            modelValue: t.value,
            "onUpdate:modelValue": l[1] || (l[1] = (e) => t.value = e),
            placeholder: "\u8BF7\u9009\u62E9\u57CE\u5E02",
            clearable: "",
            filterable: "",
            disabled: !u.value
          }, a.cityAttrs), {
            default: m(() => [
              (c(!0), V(A, null, E(s(p), (e) => (c(), d(r, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"]),
          b(o, _({
            modelValue: n.value,
            "onUpdate:modelValue": l[2] || (l[2] = (e) => n.value = e),
            placeholder: "\u8BF7\u9009\u62E9\u533A\u57DF",
            clearable: "",
            filterable: "",
            disabled: !u.value || !t.value
          }, a.areaAttrs), {
            default: m(() => [
              (c(!0), V(A, null, E(s(C), (e) => (c(), d(r, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
export {
  j as default
};
